@@ -117,6 +117,18 @@ class ManualAnonimisation(TablePolicy):
     pass
 
 
+"""
+Generic objects that are associated to Table. It can be a property of various process in a Table.
+"""
+
+class ExternalTableProperties(object):
+    def __init__(self, location, configs=None):
+        self.location = location
+        self.configs = configs or {}
+
+    def get_properies(self):
+        raise NotImplemented()
+
 """
 Generic objects that are associated to Tables. It can be a property of the table
 or a column itself.
@@ -423,8 +435,11 @@ class Table(object):
     def table_name_with_prefix(self):
         return self.table_prefix + self.table_name
 
+    def get_properties(self):
+        return self._props
+
     def get_property_by_type(self, type):
-        for p in self.properties:
+        for p in self.get_properties():
             if isinstance(p, type):
                 return p
 
